@@ -108,7 +108,7 @@ class tion(TionDummy):
         # states
         self._in_temp: int = 0
         self._out_temp: int = 0
-        self._target_temp: int = 0
+        self._heater_temp: int = 0
         self._fan_speed: int = 0
         self._mode: int = 0
         self._state: bool = False
@@ -184,7 +184,7 @@ class tion(TionDummy):
             "mode": self.mode,
             "out_temp": self.out_temp,
             "in_temp": self.in_temp,
-            "heater_temp": self.target_temp,
+            "heater_temp": self._heater_temp,
             "fan_speed": self.fan_speed,
             "filter_remain": self.filter_remain,
             "time": strftime("%H:%M", localtime()),
@@ -195,13 +195,13 @@ class tion(TionDummy):
     def __detect_heating_state(self,
                                in_temp: int = None,
                                out_temp: int = None,
-                               target_temp: int = None,
+                               heater_temp: int = None,
                                heater: str = None) -> None:
         """
         Tries to guess is heater working right now
         :param in_temp: air intake temperature
         :param out_temp: ait outtake temperature
-        :param target_temp: target temperature for heater
+        :param heater_temp: target temperature for heater
         :param heater: heater state
         :return: None
         """
@@ -209,25 +209,24 @@ class tion(TionDummy):
             in_temp = self.in_temp
         if out_temp is None:
             out_temp = self.out_temp
-        if target_temp is None:
-            target_temp = self.target_temp
+        if heater_temp is None:
+            heater_temp = self.heater_temp
         if heater is None:
             heater = self.heater
 
         if heater == "off":
             self.heating = "off"
         else:
-            if in_temp < target_temp and out_temp - target_temp < 3:
+            if heater_temp - in_temp > 3 and out_temp > in_temp:
                 self.heating = "on"
             else:
                 self.heating = "off"
 
-    def get(self, keep_connection: bool = False) -> dict:
+    def get_state_from_breezer(self, keep_connection: bool = False) -> None:
         """
-        Get current device state
+        Get current state from breezer
         :param keep_connection: should we keep connection to device or disconnect after getting data
-        :return:
-          dictionary with device state
+        :return: None
         """
         try:
             self.connect()
@@ -242,11 +241,39 @@ class tion(TionDummy):
 
         self._decode_response(response)
         self.__detect_heating_state()
+
+    def get(self, keep_connection: bool = False, skip_update: bool = False) -> dict:
+        """
+        Report current breezer state
+        :param skip_update: may we skip requesting data from breezer or not
+        :param keep_connection: should we keep connection to device or disconnect after getting data
+        :return:
+          dictionary with device state
+        """
+        if skip_update and self.have_breezer_state:
+            _LOGGER.debug(f"Skipping getting state from breezer because skip_update={skip_update} and "
+                          f"have_breezer_state={self.have_breezer_state}")
+        else:
+            self.get_state_from_breezer(keep_connection)
         common = self.__generate_common_json()
         model_specific_data = self._generate_model_specific_json()
 
         return {**common, **model_specific_data}
 
+    def _set_internal_state_from_request(self, request: dict) -> None:
+        """
+        Set internal parameters based on user request
+        :param request: changed breezer parameter from set request
+        :return: None
+        """
+        for p in ['fan_speed', 'heater_temp', 'heater', 'sound', 'mode', 'state']:
+            # ToDo: lite have additional parameters to set: "light" and "co2_auto_control", so we should get this
+            #  list from class
+            try:
+                setattr(self, p, request[p])
+            except KeyError:
+                pass
+
     def set(self, new_settings=None) -> None:
         """
         Set new breezer state
@@ -265,13 +292,14 @@ class tion(TionDummy):
 
         try:
             self.connect()
-            current_settings = self.get()
+            current_settings = self.get(skip_update=True)
 
             merged_settings = {**current_settings, **new_settings}
 
             encoded_request = self._encode_request(merged_settings)
             _LOGGER.debug("Will write %s", encoded_request)
             self._send_request(encoded_request)
+            self._set_internal_state_from_request(new_settings)
         finally:
             self.disconnect()
 
@@ -431,13 +459,21 @@ class tion(TionDummy):
     def heater(self, new_state: str):
         self._heater = self._encode_state(new_state)
 
+    @property
+    def heater_temp(self) -> int:
+        return self._heater_temp
+
+    @heater_temp.setter
+    def heater_temp(self, new_temp: int):
+        self._heater_temp = new_temp
+
     @property
     def target_temp(self) -> int:
-        return self._target_temp
+        return self.heater_temp
 
     @target_temp.setter
     def target_temp(self, new_temp: int):
-        self._target_temp = new_temp
+        self.heater_temp = new_temp
 
     @property
     def in_temp(self):
@@ -473,6 +509,10 @@ class tion(TionDummy):
     def mode(self):
         return self._process_mode(self._mode)
 
+    @mode.setter
+    def mode(self, new_state: str):
+        self._mode = self._encode_mode(new_state)
+
     @property
     def model(self) -> str:
         return self._model
@@ -542,6 +582,7 @@ class tion(TionDummy):
             self.__connections_count = 0
 
         if self.__connections_count == 0:
+            self.have_breezer_state = False
             self._connect()
 
         self.__connections_count += 1
@@ -550,6 +591,7 @@ class tion(TionDummy):
         self.__connections_count -= 1
         if self.__connections_count <= 0:
             self._disconnect()
+            self.have_breezer_state = False
 
     @property
     @abc.abstractmethod
